# adapter-bus

> a non-regulated, ~1 A, DC bus.

|   |   |   |
| --- | --- | --- |
| [![image](https://github.com/kamangir/bluer-designs/blob/main/adapter-bus/wiring.png?raw=true)](https://github.com/kamangir/bluer-designs/blob/main/adapter-bus/wiring.svg) | [![image](https://github.com/kamangir/assets2/raw/main/adapter-bus/20251017_222911.jpg?raw=true)](https://github.com/kamangir/assets2/raw/main/adapter-bus/20251017_222911.jpg?raw=true) | [![image](https://github.com/kamangir/assets2/raw/main/adapter-bus/20251017_222929.jpg?raw=true)](https://github.com/kamangir/assets2/raw/main/adapter-bus/20251017_222929.jpg?raw=true) |
| [![image](https://github.com/kamangir/assets2/raw/main/adapter-bus/20251017_222938.jpg?raw=true)](https://github.com/kamangir/assets2/raw/main/adapter-bus/20251017_222938.jpg?raw=true) | [![image](https://github.com/kamangir/assets2/raw/main/adapter-bus/20251017_222943.jpg?raw=true)](https://github.com/kamangir/assets2/raw/main/adapter-bus/20251017_222943.jpg?raw=true) | [![image](https://github.com/kamangir/assets2/raw/main/adapter-bus/20251017_222949.jpg?raw=true)](https://github.com/kamangir/assets2/raw/main/adapter-bus/20251017_222949.jpg?raw=true) |
| [![image](https://github.com/kamangir/assets2/raw/main/adapter-bus/20251017_223017.jpg?raw=true)](https://github.com/kamangir/assets2/raw/main/adapter-bus/20251017_223017.jpg?raw=true) | [![image](https://github.com/kamangir/assets2/raw/main/adapter-bus/20251017_223034.jpg?raw=true)](https://github.com/kamangir/assets2/raw/main/adapter-bus/20251017_223034.jpg?raw=true) | [![image](https://github.com/kamangir/assets2/raw/main/adapter-bus/20251018_213244.jpg?raw=true)](https://github.com/kamangir/assets2/raw/main/adapter-bus/20251018_213244.jpg?raw=true) |

## parts

|   |   |   |
| --- | --- | --- |
| [`DC power jack, 5.5 mm`](./parts/dc-power-jack.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/charger-socket.jpg?raw=true)](./parts/dc-power-jack.md)  | [`DC power plug, 5.5 mm`](./parts/dc-power-plug.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/charging-port.jpg?raw=true)](./parts/dc-power-plug.md)  | [`DSN-VC288, panel mount, 4-30 VDC, 10A (50A with shunt resistor), voltmeter ammeter`](./parts/dsn-vc288.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/dsn-vc288.jpg?raw=true)](./parts/dsn-vc288.md)  |

1. [DC power jack, 5.5 mm](./parts/dc-power-jack.md).
1. [DC power plug, 5.5 mm](./parts/dc-power-plug.md).
1. [DSN-VC288, panel mount, 4-30 VDC, 10A (50A with shunt resistor), voltmeter ammeter](./parts/dsn-vc288.md).
